@@ -1,6 +1,6 @@
 """Main library."""
-import A
-import B
+from A import A
+from B import B
 
 __version__ = "0.0.1"
 
